@@ -7,12 +7,7 @@ import os
 import sys
 import os.path as osp
 import struct
-try:
-    # Python 2
-    import _winreg as winreg
-except ImportError:
-    # Python 3
-    import winreg  # analysis:ignore
+import winreg
 
 
 EWS = "Edit with Spyder"
@@ -134,14 +129,13 @@ def install():
     if not osp.exists(script): # if not installed to the site scripts dir
         script = osp.abspath(osp.join(osp.dirname(osp.abspath(__file__)), 'spyder'))
     workdir = "%HOMEDRIVE%%HOMEPATH%"
-    import distutils.sysconfig
-    lib_dir = distutils.sysconfig.get_python_lib(plat_specific=1)
+    lib_dir = sysconfig.get_path("platlib")
     ico_dir = osp.join(lib_dir, 'spyder', 'windows')
     # if user is running -install manually then icons are in Scripts/
     if not osp.isdir(ico_dir):
         ico_dir = osp.dirname(osp.abspath(__file__))
 
-    desc = 'Scientific Python Development EnvironmEnt, an alternative to IDLE'
+    desc = 'The Scientific Python Development Environment'
     fname = osp.join(start_menu, 'Spyder (full).lnk')
     create_shortcut(python, desc, fname, '"%s"' % script, workdir,
                     osp.join(ico_dir, 'spyder.ico'))
@@ -164,7 +158,7 @@ def install():
     # Create desktop shortcut file
     desktop_folder = get_special_folder_path("CSIDL_DESKTOPDIRECTORY")
     fname = osp.join(desktop_folder, 'Spyder.lnk')
-    desc = 'Scientific Python Development EnvironmEnt, an alternative to IDLE'
+    desc = 'The Scientific Python Development Environment'
     create_shortcut(pythonw, desc, fname, '"%s"' % script, workdir,
                     osp.join(ico_dir, 'spyder.ico'))
     file_created(fname)
